<?php
require_once 'config.php';

$page = isset($_GET['page']) ? (int)$_GET['page'] : 1;
$offset = ($page - 1) * HOMEPAGE_POSTS_PER_PAGE;

// Fetch posts from Supabase
$ch = curl_init();
curl_setopt($ch, CURLOPT_URL, SUPABASE_URL . "?order=date.desc&limit=" . HOMEPAGE_POSTS_PER_PAGE . "&offset=$offset");
curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
curl_setopt($ch, CURLOPT_HTTPHEADER, [
    "apikey: " . SUPABASE_API_KEY,
    "Authorization: Bearer " . SUPABASE_API_KEY
]);
$response = curl_exec($ch);
curl_close($ch);

$posts = json_decode($response, true);
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo SITE_NAME; ?></title>
    <link rel="stylesheet" href="css/style.css">
</head>
<body>
    <header>
        <img src="<?php echo SITE_LOGO; ?>" alt="Logo">
        <h1><?php echo SITE_NAME; ?></h1>
    </header>

    <main>
        <?php if (!empty($posts)): ?>
            <div class="post-grid">
                <?php foreach ($posts as $post): ?>
                    <div class="post-card">
                        <img src="<?php echo $post['image_path']; ?>" alt="<?php echo $post['post_title']; ?>" width="<?php echo THUMBNAIL_WIDTH; ?>" height="<?php echo THUMBNAIL_HEIGHT; ?>">
                        <h2><?php echo $post['post_title']; ?></h2>
                        <p><?php echo substr(strip_tags($post['post_content']), 0, 250); ?>...</p>
                        <a href="/<?php echo $post['post_path']; ?>">Read More</a>
                    </div>
                <?php endforeach; ?>
            </div>

            <!-- Pagination -->
            <div class="pagination">
                <?php if ($page > 1): ?>
                    <a href="/?page=<?php echo $page - 1; ?>">Previous</a>
                <?php endif; ?>
                <a href="/?page=<?php echo $page + 1; ?>">Next</a>
            </div>
        <?php else: ?>
            <p>No posts available.</p>
        <?php endif; ?>
    </main>
</body>
</html>